from wger.nutrition.tests.plan import *
from wger.nutrition.tests.copy_plan import *
from wger.nutrition.tests.pdf import *

from wger.nutrition.tests.ingredient import *
from wger.nutrition.tests.ingredient_overview import *
from wger.nutrition.tests.meal import *
