{% extends "template.html" %}
{% block template %}
    <h2 id="page-title">{% block title %}{% endblock %}</h2>
    <article class="ym-grid ym-gl content">
        <div class="ym-gbox-left ym-clearfix" id="main-content">
            {% block content %}{% endblock %}
        </div>
    </article>
{% endblock %}
