{% extends "base.html" %}
{% load i18n %}

{% comment %}Translators: Don't translate, this is already done by Django{% endcomment %}
{% block title %}{% trans "Password reset complete" %}{% endblock %}


{% block content %}
{% comment %}Translators: Don't translate, this is already done by Django{% endcomment %}
<p>{% trans "Your password has been set.  You may go ahead and log in now." %}</p>

{% comment %}Translators: Don't translate, this is already done by Django{% endcomment %}
<p><a href="{{ login_url }}">{% trans 'Log in' %}</a></p>

{% endblock %}
