from wger.manager.tests.index import *
from wger.manager.tests.demo_user import *
from wger.manager.tests.registration import *
from wger.manager.tests.preferences import *
from wger.manager.tests.change_password import *

from wger.manager.tests.workout import *
from wger.manager.tests.day import *
from wger.manager.tests.set import *
from wger.manager.tests.weight_log import *
from wger.manager.tests.copy_workout import *
from wger.manager.tests.pdf import *
