{% extends "base.html" %}
{% load i18n %} 
{% load manager_extras %}


<!--
        Title
-->
{% block title %}{% trans "Set details" %}{% endblock %}


<!--
        Main Content
-->
{% block content %}

<h2>{% trans "Edit" %} {{ day.description }}</h2>


<form action="{% url wger.manager.views.edit_setting workout.id set.id exercise.id None %}"
      method="post"
      class="ym-form">
    {% csrf_token %}
    {{ setting_form.management_form }}
    {{ setting_form.non_field_errors }}

<table>
    {% for form in setting_form %}
        {{ form.id }} <!-- Needed for FormSets --> 
        {% yaml_form_field form.reps %}
    {% endfor %}
   <tr>
        <td><input type="submit" value="{% trans 'Save' %}" /></td>
        <td></td>
    </tr>
</table>
</form>


{% endblock %}


<!--
        Side bar
-->
{% block sidebar %}
{% endblock %}
